"""Init"""

import os
import logging

from dotenv import load_dotenv
from rival_regions_wrapper.middleware import LocalAuthentication

from . import wrapper


load_dotenv()


# get logger
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.INFO)

# create file handler
FILE_HANDLER = logging.FileHandler("output.log")
FILE_HANDLER.setLevel(logging.INFO)

# create console handler
STREAM_HANDLER = logging.StreamHandler()
STREAM_HANDLER.setLevel(logging.INFO)

# create formatter and add it to the handlers
STREAM_FORMATTER = logging.Formatter(
    "%(name)s - %(module)s - %(levelname)s - %(message)s"
)
STREAM_HANDLER.setFormatter(STREAM_FORMATTER)
FILE_FORMATTER = logging.Formatter(
    "%(asctime)s - %(name)s - %(module)s - %(levelname)s - %(message)s"
)
FILE_HANDLER.setFormatter(FILE_FORMATTER)

# add the handlers to logger
LOGGER.addHandler(STREAM_HANDLER)
LOGGER.addHandler(FILE_HANDLER)


class MissingAuthenticationError(Exception):
    """Error for missing authentication"""


RIVAL_REGIONS_USERNAME = os.environ.get("RIVAL_REGIONS_USERNAME", None)
RIVAL_REGIONS_PASSWORD = os.environ.get("RIVAL_REGIONS_PASSWORD", None)
RIVAL_REGIONS_LOGIN_METHOD = os.environ.get("RIVAL_REGIONS_LOGIN_METHOD", None)
CAPTCHA_KEY = os.environ.get("CAPTCHA_KEY", None)

if None in (
    RIVAL_REGIONS_USERNAME,
    RIVAL_REGIONS_PASSWORD,
    RIVAL_REGIONS_LOGIN_METHOD,
):
    raise MissingAuthenticationError(
        "Load the following variables in your user environment: "
        "RIVAL_REGIONS_USERNAME, RIVAL_REGIONS_PASSWORD, RIVAL_REGIONS_LOGIN_METHOD"
    )

RR_WRAPPER = LocalAuthentication(False, CAPTCHA_KEY)
RR_WRAPPER.set_credentials(
    RIVAL_REGIONS_USERNAME, RIVAL_REGIONS_PASSWORD, RIVAL_REGIONS_LOGIN_METHOD
)

PROFILE_ID = wrapper.Profile(RR_WRAPPER).info()["profile_id"]
